@@ -110,7 +110,7 @@ station / podcast / video.  The purpose is that one needs one of these URLs
 in order to have the option to stream the station / video in one's own choice 
 of media player software rather than using their web browser and accepting 
 flash, ads, javascript, cookies, trackers, web-bugs, and other 
-crapware associated with that method of playing.  The author uses his own 
+crapware associated with that method of play.  The author uses his own 
 custom all-purpose media player called "Fauxdacious" (his custom hacked 
 version of the open-source "Audacious" audio player).  "Fauxdacious" 
 (L<https://wildstar84.wordpress.com/fauxdacious/> incorporates this module to 
@@ -129,9 +129,10 @@ The currently-supported websites are:  banned.video
 iheartradio.com (L<StreamFinder::IHeartRadio>), podcasts.apple.com 
 (L<StreamFinder::Apple>), radio.net (L<StreamFinder::RadioNet>), 
 radionomy.com (L<StreamFinder::Radionomy>), reciva.com (L<StreamFinder::Reciva>), 
+spreaker.com podcasts (L<StreamFinder::Spreaker>), 
 tunein.com (L<StreamFinder::Tunein>), vimeo.com (L<StreamFinder::Vimeo>), 
-and (youtube.com, et. al and other sites that 
-youtube-dl supports) (L<StreamFinder::Youtube>).  
+and (youtube.com, et. al and other sites that youtube-dl supports) 
+(L<StreamFinder::Youtube>).  
 
 NOTE:  Facebook (Streamfinder::Facebook) has been removed because 
 logging into Facebook via the call to youtube-dl is now interpreted by 
@@ -139,6 +140,8 @@ Facebook as a "rogue app. login" and will cause them to LOCK your account
 and FORCE you to change your password the next time you log in 
 to Facebook!
 
+NOTE:  Radionomy appears to be defunct.
+
 NOTE:  For some sites, ie. Youtube, Vimeo, Brighteon, and BannedVideo, etc. 
 the "station" object actually refers to a specific video or podcast, but 
 functions the same way.
@@ -310,7 +313,7 @@ L<URI::Escape>, L<HTML::Entities>, L<LWP::UserAgent>
 
 =head1 RECCOMENDS
 
-youtube-dl (for Brighteon, Tunein, Vimeo)
+youtube-dl (for Youtube, Brighteon, Tunein, Vimeo)
 
 wget
 
@@ -402,7 +405,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.28';
+our $VERSION = '1.29';
 our $DEBUG = 0;
 
 require Exporter;
