@@ -50,6 +50,10 @@ file.
 
 	print "Artist=$artist\n"  if ($artist);
 	
+	my $albumartist = $video->{'albumartist'};
+
+	print "Album Artist=$albumartist\n"  if ($albumartist);
+	
 	my $icon_url = $video->getIconURL();
 
 	if ($icon_url) {   #SAVE THE ICON TO A TEMP. FILE:
@@ -88,7 +92,7 @@ for that video.  The purpose is that one needs this URL in order to have
 the option to stream the video in one's own choice of media player 
 software rather than using their web browser and accepting any / all flash, 
 ads, javascript, cookies, trackers, web-bugs, and other crapware that can 
-come with that method of playing.  The author uses his own custom all-purpose 
+come with that method of play.  The author uses his own custom all-purpose 
 media player called "fauxdacious" (his custom hacked version of the 
 open-source "audacious" audio player).  "fauxdacious" incorporates this 
 module to decode and play brighteon.com videos.  This is a submodule of the 
@@ -404,6 +408,7 @@ sub new
 	$self->{'title'} = '';
 	$self->{'description'} = '';
 	$self->{'artist'} = '';
+	$self->{'albumartist'} = '';
 	$self->{'streams'} = [];
 	$self->{'cnt'} = 0;
 
@@ -485,10 +490,10 @@ sub new
 	if ($html =~ s#\<a\s+href\=\"([^\"]*)\"\s+title\=\"[^\"]*\"\s+class\=\"author\_\_name\"\>([^\<]+)\<##s) {
 		my $one = $1;
 		($self->{'artist'} = $2) =~ s/\s+$//;
-		$self->{'artist'} .= ' - https://www.brighteon.com' . $one  if ($one);
+		$self->{'albumartist'} = 'https://www.brighteon.com' . $one  if ($one);
 	} elsif ($html =~ m#\"shortUrl\"\:\"([^\"]+)\"\,\"name\"\:\"([^\"]+)\"#) {
 		$self->{'artist'} = $2;
-		$self->{'artist'} .= " - http://www.brighteon.com/channel/$1"  if ($1);
+		$self->{'albumartist'} = "http://www.brighteon.com/channel/$1"  if ($1);
 	}
 	my $id = $self->{'id'};
 	$self->{'title'} = ($html =~ m#\<div\s+class\=\"main\-video\-title\"\>([^\<]+)\<#s) ? $1 : '';
