@@ -309,6 +309,7 @@ use LWP::UserAgent ();
 use vars qw(@ISA @EXPORT);
 
 my $DEBUG = 0;
+my $bummer = ($^O =~ /MSWin/);
 my %uops = ();
 my @userAgentOps = ();
 
@@ -325,7 +326,10 @@ sub new
 	my $self = {};
 	return undef  unless ($url);
 
-	foreach my $p ("$ENV{HOME}/.config/StreamFinder/config", "$ENV{HOME}/.config/StreamFinder/Reciva/config") {
+	my $homedir = $bummer ? $ENV{'HOMEDRIVE'} . $ENV{'HOMEPATH'} : $ENV{'HOME'};
+	$homedir ||= $ENV{'LOGDIR'}  if ($ENV{'LOGDIR'});
+	$homedir =~ s#[\/\\]$##;
+	foreach my $p ("${homedir}/.config/StreamFinder/config", "${homedir}/.config/StreamFinder/Reciva/config") {
 		if (open IN, $p) {
 			my ($atr, $val);
 			while (<IN>) {
