@@ -44,13 +44,21 @@ file.
 
 	print "Station ID=$stationID\n";
 	
+	my $genre = $station->{'genre'};
+
+	print "Genre=$genre\n"  if ($genre);
+	
 	my $artist = $station->{'artist'};
 
 	print "Artist=$artist\n"  if ($artist);
 	
-	my $genre = $station->{'genre'};
+	my $album = $video->{'album'};
 
-	print "Genre=$genre\n"  if ($genre);
+	print "Album (podcast)=$album\n"  if ($album);
+	
+	my $albumartist = $video->{'albumartist'};
+
+	print "Album Artist=$albumartist\n"  if ($albumartist);
 	
 	my $icon_url = $station->getIconURL();
 
@@ -90,7 +98,7 @@ The purpose is that one needs one of these URLs in order to have the option to
 stream the station in one's own choice of media player software rather than 
 using their web browser and accepting any / all flash, ads, javascript, 
 cookies, trackers, web-bugs, and other crapware that can come with that method 
-of playing.  The author uses his own custom all-purpose media player called 
+of play.  The author uses his own custom all-purpose media player called 
 "fauxdacious" (his custom hacked version of the open-source "audacious" 
 audio player).  "fauxdacious" can incorporate this module to decode and play 
 Tunein.com streams.  One or more streams can be returned for each station.  
@@ -400,19 +408,17 @@ sub new
 	$html =~ s/\\\"/\&quot\;/gs;
 	if ($html) {  #EXTRACT METADATA, IF WE CAN:
 		print STDERR "-1: EXTRACTING METADATA...\n"  if ($DEBUG);
-		my $artist;
 		$self->{'id'} = $1  if ($html =~ m#\"guideId\"\:\"([^\"]+)\"#);
 		$self->{'fccid'} = ($html =~ m#\"callSign\"\:\"([^\"]+)\"#i) ? $1 : '';
 		$self->{'title'} = ($html =~ m#\"twitter\:title\"\s+content\=\"([^\"]+)\"#) ? $1 : '';
-		$self->{'description'} = $self->{'title'};
-		$artist = ($html =~ m#\"title\"\:\"([^\"]+)\"#) ? $1 : '';
-		$artist ||= ($html =~ m# title\=\"([^\"]+)\" #) ? $1 : '';
-		if ($artist && $self->{'title'} !~ /\w/) {
-			$self->{'title'} = $artist;
-			$artist = '';
+		$self->{'album'} ||= ($html =~ m#\<h1\s+data\-testid\=\"profileTitle\"\s+title\=\"([^\"]+)\"#) ? $1 : '';
+		if ($self->{'title'} !~ /\S/) {
+			$self->{'title'} = $self->{'album'};
+			$self->{'album'} = '';
 		}
-		$self->{'artist'} = ($html =~ m#\"subtitle\"\:\"([^\"]+)\"#i) ? $1 : '';
-		$self->{'description'} = ($html =~ m#name\=\"twitter\:description\"\s+content\=\"([^\"]+)\"#i) ? $1 : $self->{'title'};
+		$self->{'description'} = $self->{'title'};
+		$self->{'artist'} = ($html =~ m#\"profileSubtitle\"\>([^\<]+)#) ? $1 : '';
+		$self->{'description'} = $1  if ($html =~ m#name\=\"twitter\:description\"\s+content\=\"([^\"]+)\"#i);
 		$self->{'description'} = HTML::Entities::decode_entities($self->{'description'});
 		$self->{'description'} = uri_unescape($self->{'description'});
 		$self->{'iconurl'} = ($html =~ m#\"twitter\:image\:src\"\s+content\=\"([^\"]+)\"#) ? $1 : '';
@@ -424,18 +430,14 @@ sub new
 		$self->{'imageurl'} =~ s#\?.+$##;
 		if ($self->{'artist'} =~ /\S/) {
 			$self->{'artist'} =~ s/\s*\\?u?003E\s*$//;
-			$artist .= ' - '  if ($artist);
-			$artist .= $self->{'artist'}
-		}
-		if ($artist) {
-			$artist = HTML::Entities::decode_entities($artist);
-			$artist = uri_unescape($artist);
-			$self->{'artist'} = $artist;
+			$self->{'artist'} = HTML::Entities::decode_entities($self->{'artist'});
+			$self->{'artist'} = uri_unescape($self->{'artist'});
 		}
 		my $genre = ($html =~ m#\"rootGenre\"\:\"([^\"]+)\"#) ? $1 : '';
 		my $subgenre = ($html =~ m#\"primaryGenreName\"\:\"([^\"]+)\"#) ? $1 : '';
 		if ($genre && $subgenre) {
-			$self->{'genre'} = ($genre eq 'music') ? $subgenre : $genre . ' - ' . $subgenre;
+			#$self->{'genre'} = ($genre eq 'music') ? $subgenre : $genre . ' - ' . $subgenre;
+			$self->{'genre'} = ($genre =~ /music/i) ? $subgenre : $genre;
 		} elsif ($genre) {
 			$self->{'genre'} = $genre;
 		} elsif ($subgenre) {
@@ -464,7 +466,7 @@ sub new
 		$self->{'created'} = $1  if ($html =~ s#\"publishTime\"\:\"([^\"]*)\"\,STREAMFINDER_MARK##i);
 		$self->{'year'} = (defined($self->{'created'}) && $self->{'created'} =~ /(\d\d\d\d)/) ? $1 : '';
 		print STDERR "i:Podcast found, ID changed to (".$self->{'id'}."), year (".$self->{'year'}.").\n"  if ($DEBUG);
-	} else {  #(USUALLY) NO STREAMS FOUND, TRY youtube-dl!:
+	} else {  #(USUALLY) NO STREAMS FOUND, TRY youtube-dl! (PBLY A STATION):
 		my $tryStream = "http://opml.radiotime.com/Tune.ashx?id=$stationID";
 		if ($haveYoutube) {
 			$_ = `youtube-dl --get-url  "$tryStream"`;
@@ -474,11 +476,16 @@ sub new
 				shift @urls;
 			}
 			if (scalar(@urls) > 0) {
+				for (my $i=0;$i<=$#urls;$i++) {
+					$urls[$i] =~ s/\.pls\?.+$/\.pls/;  #CLEAN UP TUNEIN PLS PLAYLISTS.
+				}
 				print STDERR "i:Found stream(s) (".join('|',@urls).") via youtube-dl.\n"  if ($DEBUG);
 				@{$self->{'streams'}} = @urls;
 				$self->{'cnt'} = scalar @urls;
 			}
 		}
+		$self->{'album'} = $self->{'artist'};
+		$self->{'artist'} = '';  #ONLY PODCASTS HAVE ARTISTS, NOT STATIONS!
 	}
 	$self->{'total'} = $self->{'cnt'};
 	$self->{'title'} = HTML::Entities::decode_entities($self->{'title'});
