@@ -50,6 +50,10 @@ file.
 
 	print "Artist=$artist\n"  if ($artist);
 	
+	my $albumartist = $video->{'albumartist'};
+
+	print "Album Artist=$albumartist\n"  if ($albumartist);
+	
 	my $icon_url = $video->getIconURL();
 
 	if ($icon_url) {   #SAVE THE ICON TO A TEMP. FILE:
@@ -88,7 +92,7 @@ for that video.  The purpose is that one needs this URL in order to have
 he option to stream the video in one's own choice of media player 
 software rather than using their web browser and accepting any / all 
 flash, ads, javascript, cookies, trackers, web-bugs, and other crapware 
-that can come with that method of playing.  The author uses his own 
+that can come with that method of play.  The author uses his own 
 custom all-purpose media player called "fauxdacious" (his custom hacked 
 version of the open-source "audacious" audio player).  "fauxdacious" 
 incorporates this module to decode and play vimeo.com videos.  This is a 
@@ -329,7 +333,7 @@ sub new
 
 	my $self = {};
 	return undef  unless ($url);
-	return undef  if ($url =~ /\bplayer\.vimeo\b/);
+#	return undef  if ($url =~ /\bplayer\.vimeo\b/);
 
 	my $homedir = $bummer ? $ENV{'HOMEDRIVE'} . $ENV{'HOMEPATH'} : $ENV{'HOME'};
 	$homedir ||= $ENV{'LOGDIR'}  if ($ENV{'LOGDIR'});
@@ -379,6 +383,7 @@ sub new
 	$self->{'title'} = '';
 	$self->{'description'} = '';
 	$self->{'artist'} = '';
+	$self->{'albumartist'} = '';
 	$self->{'streams'} = [];
 	$self->{'cnt'} = 0;
 
@@ -427,7 +432,7 @@ sub new
 			}
 			if ($cnt) {
 				$self->{'artist'} = $1  if ($html =~ s#\"owner\"\:\{.*?\"name\"\:\"([^\"]+)\"#STREAMFINDERMARK#s);
-				$self->{'artist'} .= ' - ' . $1  if ($html =~ s#STREAMFINDERMARK.*?\"url\"\:\"([^\"]+)\"##s);
+				$self->{'albumartist'} = $1  if ($html =~ s#STREAMFINDERMARK.*?\"url\"\:\"([^\"]+)\"##s);
 			}
 		}
 	}
