@@ -48,7 +48,11 @@ file.
 	
 	my $artist = $video->{'artist'};
 
-	print "Artist=$artist\n"  if ($artist);
+	print "Artist (channel)=$artist\n"  if ($artist);
+	
+	my $albumartist = $video->{'albumartist'};
+
+	print "Album Artist (Channel URL)=$albumartist\n"  if ($albumartist);
 	
 	my $icon_url = $video->getIconURL();
 
@@ -89,7 +93,7 @@ The purpose is that one needs this URL in order to have the option to
 stream the video in one's own choice of media player software rather 
 than using their web browser and accepting any / all flash, ads, 
 javascript, cookies, trackers, web-bugs, and other crapware that can 
-come with that method of playing.  The author uses his own custom all-purpose 
+come with that method of play.  The author uses his own custom all-purpose 
 media player called "fauxdacious" (his custom hacked version of the 
 open-source "audacious" audio player).  "fauxdacious" incorporates this 
 module to decode and play youtube.com videos.  This is a submodule of the 
@@ -377,6 +381,7 @@ sub new
 	$self->{'iconurl'} = '';
 	$self->{'title'} = '';
 	$self->{'artist'} = '';
+	$self->{'albumartist'} = '';
 
 	#FIRST:  GET STREAMS, THUMBNAIL, ETC. FROM youtube-dl:
 
@@ -452,7 +457,7 @@ RETRYIT:
 		if ($html =~ s#\]\}\,\"title\"\:\{\"runs\"\:\[\{\"text\"\:\"([^\"]+)\"\,\"navigationEndpoint\"\:([^\}]+)##s) {
 			my $two = $2;
 			$self->{'artist'} = $1;
-			$self->{'artist'} .= ' - https://www.youtube.com' . $1  if ($two =~ m#\"url\"\:\"([^\"]+)#);
+			$self->{'albumartist'} = 'https://www.youtube.com' . $1  if ($two =~ m#\"url\"\:\"([^\"]+)#);
 		}
 		if ($html =~ s#\"videoDetails\"\:\{\"videoId\"\:\"([^\"]+)\"([^\}]+)##s) {
 			my $two = $2;
@@ -476,7 +481,7 @@ RETRYIT:
 	} else {
 		$self->{'description'} = $self->{'title'};
 	}
-	foreach my $i (qw(title artist description)) {
+	foreach my $i (qw(title artist albumartist description)) {
 		$self->{$i} = HTML::Entities::decode_entities($self->{$i});
 		$self->{$i} = uri_unescape($self->{$i});
 		$self->{$i} =~ s/(?:\%|\\?u?00)([0-9A-Fa-f]{2})/chr(hex($1))/egso;
